@@ -96,10 +96,11 @@ void PartPropsDialog::setupDialog()
 	enableButtonOk(false);
 	button(KDialog::Cancel)->setFocus();
 
-	dialogWidget().partResizerWidget().setReadOnly(true);
-	dialogWidget().partResizerWidget().init(device(), partition(), 0, 0);
+	dialogWidget().partWidget().init(&partition());
 
-	const QString mp = partition().mountPoints().size() == 0 ? i18nc("@item mountpoint", "(none found)") : partition().mountPoints().join(", ");
+	const QString mp = partition().mountPoint().isEmpty()
+			? i18nc("@item mountpoint", "(none found)")
+			: partition().mountPoint();
 	dialogWidget().mountPoint().setText(mp);
 
 	dialogWidget().role().setText(partition().roles().toString());
@@ -109,7 +110,7 @@ void PartPropsDialog::setupDialog()
 	{
 		if (partition().roles().has(PartitionRole::Extended))
 			statusText = i18nc("@label partition state", "At least one logical partition is mounted.");
-		else if (partition().mountPoints().size() > 0)
+		else if (!partition().mountPoint().isEmpty())
 			statusText = i18nc("@label partition state", "mounted on <filename>%1</filename>", mp);
 		else
 			statusText = i18nc("@label partition state", "mounted");
@@ -122,16 +123,27 @@ void PartPropsDialog::setupDialog()
 
 	 // don't do this before the file system combo box has been set up!
 	dialogWidget().label().setText(newLabel().isEmpty() ? partition().fileSystem().label() : newLabel());
-	dialogWidget().capacity().setText(Capacity(partition()).toString(Capacity::AppendUnit | Capacity::AppendBytes));
+	dialogWidget().capacity().setText(Capacity::formatByteSize(partition().capacity()));
 
-	const Capacity availableCapacity = Capacity(partition(), Capacity::Available);
-	const QString availString = availableCapacity.isValid() ? QString(" - %1").arg(availableCapacity.toString(Capacity::AppendUnit | Capacity::AppendBytes)) : QString();
-	const qint64 availPercent = (partition().fileSystem().length() - partition().fileSystem().sectorsUsed()) * 100 / partition().fileSystem().length();
-	dialogWidget().available().setText(QString("%1%%2").arg(QString::number(availPercent)).arg(availString));
+	if (Capacity(partition(), Capacity::Available).isValid())
+	{
+		const qint64 availPercent = (partition().fileSystem().length() - partition().fileSystem().sectorsUsed()) * 100 / partition().fileSystem().length();
 
-	const Capacity usedCapacity = Capacity(partition(), Capacity::Used);
-	const QString usedString = usedCapacity.isValid() ? QString(" - %1").arg(usedCapacity.toString(Capacity::AppendUnit | Capacity::AppendBytes)) : QString();
-	dialogWidget().used().setText(QString("%1%%2").arg(QString::number(100 - availPercent)).arg(usedString));
+		const QString availString = QString("%1% - %2")
+			.arg(availPercent)
+			.arg(Capacity::formatByteSize(partition().available()));
+		const QString usedString = QString("%1% - %2")
+			.arg(100 - availPercent)
+			.arg(Capacity::formatByteSize(partition().used()));
+
+		dialogWidget().available().setText(availString);
+		dialogWidget().used().setText(usedString);
+	}
+	else
+	{
+		dialogWidget().available().setText(Capacity::invalidString());
+		dialogWidget().used().setText(Capacity::invalidString());
+	}
 
 	dialogWidget().firstSector().setText(KGlobal::locale()->formatNumber(partition().firstSector(), 0));
 	dialogWidget().lastSector().setText(KGlobal::locale()->formatNumber(partition().lastSector(), 0));
@@ -169,7 +181,7 @@ void PartPropsDialog::updateHideAndShow()
 	// create a temporary fs for some checks
 	const FileSystem* fs = FileSystemFactory::create(newFileSystemType(), -1, -1, -1, "");
 
-	if (fs == NULL || fs->supportSetLabel() == FileSystem::SupportNone)
+	if (fs == NULL || fs->supportSetLabel() == FileSystem::cmdSupportNone)
 	{
 		dialogWidget().label().setReadOnly(true);
 		dialogWidget().noSetLabel().setVisible(true);
@@ -190,7 +202,7 @@ void PartPropsDialog::updateHideAndShow()
 	// when do we show the uuid?
 	const bool showUuid =
 			partition().state() != Partition::StateNew &&                           // not for new partitions
-			!(fs == NULL || fs->supportGetUUID() == FileSystem::SupportNone);       // not if the FS doesn't support it
+			!(fs == NULL || fs->supportGetUUID() == FileSystem::cmdSupportNone);       // not if the FS doesn't support it
 
 	dialogWidget().showUuid(showUuid);
 
@@ -216,7 +228,7 @@ void PartPropsDialog::updateHideAndShow()
 	// when do we show the recreate file system check box?
 	const bool showCheckRecreate =
 			showFileSystem &&                                                       // only if we also show the file system
-			partition().fileSystem().supportCreate() != FileSystem::SupportNone &&  // and support creating this file system
+			partition().fileSystem().supportCreate() != FileSystem::cmdSupportNone &&  // and support creating this file system
 			partition().fileSystem().type() != FileSystem::Unknown &&               // and not for unknown file systems
 			partition().state() != Partition::StateNew;                             // or new partitions
 
@@ -263,7 +275,7 @@ void PartPropsDialog::setupFileSystemComboBox()
 	QStringList fsNames;
 
 	foreach(const FileSystem* fs, FileSystemFactory::map())
-		if (partition().fileSystem().type() == fs->type() || (fs->supportCreate() != FileSystem::SupportNone && partition().capacity() >= fs->minCapacity() && partition().capacity() <= fs->maxCapacity()))
+		if (partition().fileSystem().type() == fs->type() || (fs->supportCreate() != FileSystem::cmdSupportNone && partition().capacity() >= fs->minCapacity() && partition().capacity() <= fs->maxCapacity()))
 		{
 			QString name = fs->name();
 
@@ -292,8 +304,21 @@ void PartPropsDialog::setupFileSystemComboBox()
 
 	qSort(fsNames.begin(), fsNames.end(), caseInsensitiveLessThan);
 
-	dialogWidget().fileSystem().addItems(fsNames);
+	foreach (const QString& fsName, fsNames)
+		dialogWidget().fileSystem().addItem(createFileSystemColor(FileSystem::typeForName(fsName), 8), fsName);
+
 	dialogWidget().fileSystem().setCurrentIndex(dialogWidget().fileSystem().findText(selected));
+
+	const FileSystem* fs = FileSystemFactory::create(FileSystem::typeForName(dialogWidget().fileSystem().currentText()), -1, -1, -1, "");
+	dialogWidget().m_EditLabel->setMaxLength(fs->maxLabelLength());
+}
+
+void PartPropsDialog::updatePartitionFileSystem()
+{
+	FileSystem* fs = FileSystemFactory::create(newFileSystemType(), partition().firstSector(), partition().lastSector());
+	partition().deleteFileSystem();
+	partition().setFileSystem(fs);
+	dialogWidget().partWidget().update();
 }
 
 void PartPropsDialog::onFilesystemChanged(int)
@@ -302,12 +327,16 @@ void PartPropsDialog::onFilesystemChanged(int)
 			i18nc("@info", "<para><warning>You are about to lose all data on partition <filename>%1</filename>.</warning></para>"
 				"<para>Changing the file system on a partition already on disk will erase all its contents. If you continue now and apply the resulting operation in the main window, all data on <filename>%1</filename> will unrecoverably be lost.</para>", partition().deviceNode()),
 			i18nc("@title:window", "Really Recreate <filename>%1</filename> with File System %2?", partition().deviceNode(), dialogWidget().fileSystem().currentText()),
-			KGuiItem(i18nc("@action:button", "&Change the File System"), "arrow-right"),
-			KGuiItem(i18nc("@action:button", "&Do Not Change the File System"), "dialog-cancel"), "reallyChangeFileSystem") == KMessageBox::Continue)
+			KGuiItem(i18nc("@action:button", "Change the File System"), "arrow-right"),
+			KGuiItem(i18nc("@action:button", "Do Not Change the File System"), "dialog-cancel"), "reallyChangeFileSystem") == KMessageBox::Continue)
 	{
 		setDirty();
 		updateHideAndShow();
 		setWarnFileSystemChange();
+		updatePartitionFileSystem();
+
+		const FileSystem* fs = FileSystemFactory::create(FileSystem::typeForName(dialogWidget().fileSystem().currentText()), -1, -1, -1, "");
+		dialogWidget().m_EditLabel->setMaxLength(fs->maxLabelLength());
 	}
 	else
 	{
@@ -323,8 +352,8 @@ void PartPropsDialog::onRecreate(int state)
 			i18nc("@info", "<para><warning>You are about to lose all data on partition <filename>%1</filename>.</warning></para>"
 				"<para>Recreating a file system will erase all its contents. If you continue now and apply the resulting operation in the main window, all data on <filename>%1</filename> will unrecoverably be lost.</para>", partition().deviceNode()),
 			i18nc("@title:window", "Really Recreate File System on <filename>%1</filename>?", partition().deviceNode()),
-			KGuiItem(i18nc("@action:button", "&Recreate the File System"), "arrow-right"),
-			KGuiItem(i18nc("@action:button", "&Do Not Recreate the File System"), "dialog-cancel"), "reallyRecreateFileSystem") == KMessageBox::Continue))
+			KGuiItem(i18nc("@action:button", "Recreate the File System"), "arrow-right"),
+			KGuiItem(i18nc("@action:button", "Do Not Recreate the File System"), "dialog-cancel"), "reallyRecreateFileSystem") == KMessageBox::Continue))
 	{
 		setDirty();
 		setWarnFileSystemChange();
@@ -332,6 +361,7 @@ void PartPropsDialog::onRecreate(int state)
 		dialogWidget().fileSystem().setCurrentIndex(dialogWidget().fileSystem().findText(partition().fileSystem().name()));
 		dialogWidget().fileSystem().setEnabled(false);
 		updateHideAndShow();
+		updatePartitionFileSystem();
 	}
 	else
 	{
